@@ -1,8 +1,14 @@
-from django.contrib.auth.models import User
 from django.contrib.auth.backends import ModelBackend
 from tokenapi.tokens import token_generator
 from django.conf import settings
 
+try:
+    from django.contrib.auth import get_user_model
+except ImportError: # Django < 1.5
+    from django.contrib.auth.models import User
+else:
+    User = get_user_model()
+
 
 class TokenBackend(ModelBackend):
     def authenticate(self, pk, token):
