@@ -1,11 +1,18 @@
 import json
 
 from django.test import TestCase
-from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 
+try:
+    from django.contrib.auth import get_user_model
+except ImportError: # Django < 1.5
+    from django.contrib.auth.models import User
+else:
+    User = get_user_model()
+
 from tokenapi.tokens import token_generator
 
+
 class TokenManagementTestCase(TestCase):
     username = "jpulgarin"
     email = "jp@julianpulgarin.com"
